==> jaxrs-ri-2.5-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/internal/routing/PathPatternRouteBuilder.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.internal.routing;

import javax.inject.Inject;

import org.glassfish.jersey.server.internal.routing.RouterBinder.RootRouteBuilder;
import org.glassfish.jersey.server.internal.routing.RouterBinder.RouteBuilder;
import org.glassfish.jersey.server.internal.routing.RouterBinder.RouteToBuilder;
import org.glassfish.jersey.uri.PathPattern;

import org.glassfish.hk2.api.ServiceLocator;

/**
 * {@link RouteBuilder} implementation that builds routes which use {@link PathPattern}
 * to perform path matching.
 *
 * @author Paul Sandoz
 * @author Marek Potociar (marek.potociar at oracle.com)
 */
class PathPatternRouteBuilder implements RootRouteBuilder<PathPattern> {

    @Inject
    private ServiceLocator locator;
    @Inject
    private PathPatternRouter.Builder acceptorFactory;
    @Inject
    private MatchResultInitializerRouter.Builder initializerFactory;

    @Override
    public RouteToBuilder<PathPattern> route(String pattern) {
        return route(new PathPattern(pattern));
    }

    @Override
    public RouteToBuilder<PathPattern> route(PathPattern pattern) {
        return new AbstractRouteToPathBuilder<PathPattern>(locator, pattern) {

            @Override
            public RouteToBuilder<PathPattern> route(String pattern) {
                return super.route(new PathPattern(pattern));
            }

            @Override
            public Router build() {
                return acceptorFactory.build(acceptedRoutes());
            }
        };
    }

    @Override
    public Router root(Router routingRoot) {
        return initializerFactory.build(routingRoot);
    }
}

==> jaxrs-ri-2.9-src.tar.bz2: jaxrs-ri/src/org/glassfish/jersey/server/internal/routing/PathPatternRouteBuilder.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.internal.routing;

import org.glassfish.jersey.server.internal.routing.Routers.RootRouteBuilder;
import org.glassfish.jersey.server.internal.routing.Routers.RouteBuilder;
import org.glassfish.jersey.server.internal.routing.Routers.RouteToBuilder;
import org.glassfish.jersey.uri.PathPattern;

import org.glassfish.hk2.api.ServiceLocator;

/**
 * {@link RouteBuilder} implementation that builds routes which use {@link PathPattern}
 * to perform path matching.
 *
 * @author Paul Sandoz
 * @author Marek Potociar (marek.potociar at oracle.com)
 */
final class PathPatternRouteBuilder implements RootRouteBuilder<PathPattern> {

    private final ServiceLocator locator;

    /**
     * Create new {@link PathPattern}-based route builder.
     *
     * @param locator application service locator.
     */
    PathPatternRouteBuilder(final ServiceLocator locator) {
        this.locator = locator;
    }

    @Override
    public RouteToBuilder<PathPattern> route(String pattern) {
        return route(new PathPattern(pattern));
    }

    @Override
    public RouteToBuilder<PathPattern> route(PathPattern pattern) {
        return new AbstractRouteToPathBuilder<PathPattern>(locator, pattern) {

            @Override
            public RouteToBuilder<PathPattern> route(String pattern) {
                return super.route(new PathPattern(pattern));
            }

            @Override
            public Router build() {
                return new PathPatternRouter(acceptedRoutes());
            }
        };
    }

    @Override
    public Router root(Router routingRoot) {
        return new MatchResultInitializerRouter(routingRoot);
    }
}
